function p=GetCoronaParameters(country)
% fetch good parameters for Corona Analysis, depending on country
% Input country as string delivered e.g. from getCoronaCountryList.m
% just FYI: countrylist={ 'Germany' 'Brazil' 'Russia' 'Italy' 'Spain' 'Sweden' 'Austria' 
% 'France' 'UK','HongKong','US','Denmark','Switzerland'};
% actual list: see getCoronaCountryList.m
% Output:
% p=(tstart, N, estimateRecovered, timespan)
% OBSOLETE: tstart = day where systematic data start
% NEW: start at 10 deaths and 100 Confirmed at least, see the end
% N = total population (wikipedia)
% estimateRecovered = 1 if Recovered need estimation, 0 else
% Set to 1 if the Recovered data of the country are a mess
% timespan = number of days for future predicton
disp(sprintf('Getting Corona parameters for country %s',country)) 
timespan=100; % standard value, about 3 months
exmort=1;
switch country
    case 'Brazil'
        tstart=65;
        N=210e6;
        estimateRecovered=0;
        timespan=350;
    case 'Russia'
        tstart=70;
        N=144e6;
        estimateRecovered=0;
        timespan=350;
    case 'Denmark'
        tstart=65;
        N=5.8e6;
        estimateRecovered=0;
        timespan=170;
        exmort=0.79;
    case 'Switzerland'
        tstart=55;
        N=8.6e6;
        estimateRecovered=1;
        timespan=600;
    case 'Hubei'
        tstart=8;
        N=58e6;
        estimateRecovered=0;
    case 'Korea'
        tstart=31;
        N=51e6;
        estimateRecovered=0;
    case 'Germany'
        tstart=40;
        N=83e6;
        estimateRecovered=0;
        exmort=1.01;
        timespan=100
    case 'Italy'
        tstart=35;
        N=60e6;
        estimateRecovered=0;
        exmort=1.25;
        timespan=500
    case 'France'
        tstart=38;
        N=67e6;
        estimateRecovered=0;
        exmort=0.97;
        % timespan=2000 % for long-term plot
        timespan=100 % for closeup
    case 'Spain'
        tstart=35;
        N=46.6e6;
        estimateRecovered=0;
        exmort=1.55;
        % timespan=1000 % for long-term plot
        timespan=100 % for closeup
    case 'UK'
        tstart=38;
        N=67.5e6;
        estimateRecovered=1;
        timespan=250;  
        exmort=1.57;
    case 'Austria'
        tstart=31;
        N=8.95e6;
        estimateRecovered=1;
        timespan=170
        exmort=2.32
    case 'Sweden'
        tstart=43;
        N=10e6;
        estimateRecovered=1;
        timespan=150; 
        exmort=0.92;
    case 'HongKong'
        tstart=24;
        N=7.4e6;
        estimateRecovered=0;
    case 'US'
        tstart=40;
        N=372e6;
        estimateRecovered=0;
        timespan=300;   
        exmort=1.41;
    otherwise
        disp('Country not implemented, needs parameters')
        return   
end
[C, R, D]=GetCoronaDataRaw(country);
tstart=getstarttime(C, D);
% set the parameter list
% NEW
p(1)=tstart;
p(2)=N;
p(3)=estimateRecovered;
p(4)=timespan;
p(5)=exmort;
% special settings for specific runs:
% switch country
%     case 'Germany'
%         tstart=175;
%     otherwise
disp(sprintf('Corona parameters for country %s: start time =%d, population=%g, estimationRequired=%d, timespan=%d, excess mortality = %5.2f',...
    country, p(1), p(2), p(3), p(4), p(5))) 
