function SMH=calibrateSMH_series_2(C, R, D, N , gCFseries, gIFseries, H0fact, gIRseries, k, lastdayused, backlog)
%
% This calibrates the hidden SMH model from a given C data vector
% in a population of size N
% from an index tstart on, where C(tstart) must be defined 
% H0 will then be H(tstart).
% This runs to the end of C, whatever it is. 
% No smoothing of C.
%
% Input:
% 
% C = Confirmed, cumulative,
%     like in Johns Hopkins data
%
% Parameters:
%
% gIR is gamma_{IR} in the paper 
% gCFgIF is gamma_{CF}/gamma_{IF} in the paper
%
% Output: 
% 
% S = Susceptibles, 
% M = unregistered Infectious
% H = unregistered Recovered
% 
% S, M, H as full vectors of the same length as C.
% SMH is [S M H] as a matrix of 3 columns.
% S will be fully calculated.
% M, H will have zeros up to tstart, where the
% calculation begins. 
% The starting value for M is
% calculated from N=S+M+H+C at tstart, using H0.
%
len=length(C);
% get vectors as columns, full size
S=zeros(len,1);
H=zeros(len,1);
M=zeros(len,1);
% We need S(tstart) later, therefore S is calculated beforehand
S(1)=N; % canonical starting value for S 
% prepare startup for H and M
tstart=min(find(gCFseries>0))
tstart=min(tstart, lastdayused)
deltaseries=zeros(size(gCFseries));
deltaseries(tstart:len)=gIFseries(tstart:len)./gCFseries(tstart:len);
figure
plot(tstart:len,deltaseries(tstart:len))
deltaseries(1:tstart)=deltaseries(tstart);
deltastart=deltaseries(tstart)
title('Detection rate')
% Get the full S values, like in paper
for i=2:len
    S(i,1)=S(i-1,1)-(C(i)-C(i-1))/deltaseries(i);
end
% C0=C(tstart)
% Ck=C(tstart-k)
% H0fact
% H0=H0fact*Ck*gCFseries(tstart)/gIF
% H0=H0/100
% H(tstart,1)=H0;
% M(tstart,1)=N-S(tstart)-H0-C(tstart);
% % then run the SMH model like in the paper
% % C0=C(tstart)
% % H0 
% M0=M(tstart,1)
% S0=S(tstart)
% % N
% % NmS0=N-S0
% NmSmC=N-C0-S0
% neu: 
I=C-R-D;
Ilast=backestimate(I,backlog);
Rlast=backestimate(R,backlog);
% MHfact=I(lastdayused)/(I(lastdayused)+R(lastdayused));
MHfact=Ilast/(Ilast+Rlast);
M(tstart,1)=(N-S(tstart)-C(tstart))*MHfact;
H(tstart,1)=(N-S(tstart)-C(tstart))*(1-MHfact);
H0=H(tstart,1)
M0=M(tstart,1)
S0=S(tstart)
% C0=gCFseries(tstart)*C(tstart)/gIF
% figure
% plot(N-S-C)
% pause
for i=tstart+1:len
    M(i,1)=M(i-1,1)*(1-gIRseries(i))+(1/deltaseries(i-1) -1)*(C(i)-C(i-1));
    H(i,1)=H(i-1,1)+gIRseries(i)*M(i-1,1);
end
% assemble into one matrix
SMH=[S M H];
% pause
